==> phpnuke-5.5.tgz: www/phpnuke/html/modules/Web_Links/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please sent to me (fbc@mandrakesoft.com)    */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","O seu nome");
define("_CATEGORY","Categoria");
define("_CATEGORIES","Categorias");
define("_LVOTES","votos");
define("_TOTALVOTES","Total de votos:");
define("_LINKTITLE","Ttulo do Link ");
define("_HITS","Hits");
define("_THEREARE","H");
define("_NOMATCHES","Nada encontrado para");
define("_SCOMMENTS","Comentrios");
define("_DESCRIPTION","Descrio");
define("_ONLYREGUSERSMODIFY","Somente utilizadores registado podem sugerir modificaes nos arquivos para Download. Por favor <a href=\"modules.php?name=Your_Account\">registe-se ou efectue o seu login</a>.");
define("_DATE","Data");
define("_TO","Para");
define("_ADDLINK","Adicionar Link");
define("_NEW","Novo");
define("_POPULAR","Popular");
define("_TOPRATED","Melhor Colocado");
define("_RANDOM","Aleatrio");
define("_LINKSMAIN","ndice de Links");
define("_LINKCOMMENTS","Link Comentado");
define("_ADDITIONALDET","Detalhes Adicionais");
define("_EDITORREVIEW","Editor da Reviso");
define("_REPORTBROKEN","Reporte Links Invlidos");
define("_LINKSMAINCAT","ndice de Categorias de Links");
define("_AND","e");
define("_INDB","no nosso web site");
define("_ADDALINK","Adicionar Novo Link");
define("_INSTRUCTIONS","Instrues");
define("_SUBMITONCE","Envie somente uma vez um Link no envie Links iguais.");
define("_POSTPENDING","Todos os Links so verificados antes de serem publicados.");
define("_USERANDIP","So registado o nome do utilizador bem como o ip de quem enviou o Link, ento por favor no abuse ns podemos encontra-lo.");
define("_PAGETITLE","Ttulo da Pgina");
define("_PAGEURL","Endereo da Pgina");
define("_YOUREMAIL","Seu Email");
define("_LDESCRIPTION","Descrio: (255 mx. caracteres)");
define("_ADDURL","Adicionar esta URL");
define("_LINKSNOTUSER1","Voc no  um utilizador registado ou no efetuou seu login.");
define("_LINKSNOTUSER2","Se voc fosse um utilizador registado do site ento voc poderia adicionar URLS neste site.");
define("_LINKSNOTUSER3","Para se tornar um utilizador registado  rpido e simples.");
define("_LINKSNOTUSER4","Por que ns requeremos o seu registo para acessar certas reas?");
define("_LINKSNOTUSER5","Porque s assim poderemos lhe oferecer um contedo da mais alta qualidade,");
define("_LINKSNOTUSER6","pois cada item  revisado individualmente por nossa equipe.");
define("_LINKSNOTUSER7","E ns desejamos lhe oferecer somente informaes importantes.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Registe uma conta</a>");
define("_LINKALREADYEXT","ERRO: Esta URL j existe no nosso web site!");
define("_LINKNOTITLE","ERRO: Voc precisa dar uma ttulo para sua URL!");
define("_LINKNOURL","ERRO: Voc precisa digitar uma URL para sua URL!");
define("_LINKNODESC","ERRO: Voc precisa descrever sua URL!");
define("_LINKRECEIVED","Ns recebemos o seu Link. Obrigado!");
define("_EMAILWHENADD","Voc receber um Email quando este Link for aprovado.");
define("_CHECKFORIT","Voc no escreveu seu Email. De qualquer maneira nossa equipe ir conferir o seu Link");
define("_NEWLINKS","Novos Links");
define("_TOTALNEWLINKS","Total de Novos Links");
define("_LASTWEEK","Da ltima semana");
define("_LAST30DAYS","Dos ltimos 30 dias");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Dias");
define("_SHOW","Mostar");
define("_TOTALFORLAST","Total de novos Links por ltimo");
define("_DAYS","dias");
define("_ADDEDON","Adicionado em");
define("_RATING","Pdium");
define("_RATESITE","Avalie este Site");
define("_DETAILS","Detalhes");
define("_BESTRATED","Pdium do Melhores Links - Top");
define("_OF","do");
define("_TRATEDLINKS","total de sites avaliados ");
define("_TVOTESREQ","mnimo de votos requeridos");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Os mais populares - top");
define("_OFALL","de todos");
define("_SORTLINKSBY","Links ordenados por");
define("_SITESSORTED","Web sites actualmente ordenados por");
define("_POPULARITY","Popularidade");
define("_SELECTPAGE","Pgina Selecionado");
define("_MAIN","ndice");
define("_NEWTODAY","Novo de Hoje");
define("_NEWLAST3DAYS","Novo dos ltimos 3 dias");
define("_NEWTHISWEEK","Novo desta Semana");
define("_CATNEWTODAY","Novos Links desta categoria adicionados Hoje");
define("_CATLAST3DAYS","Novos Links desta categoria adicionados nos ltimos 3 dias");
define("_CATTHISWEEK","Novos Links desta categoria adicionados esta semana");
define("_POPULARITY1","Popular (Mais Visitados Primeiro)");
define("_POPULARITY2","Popular (Mais Visitados por ltimos)");
define("_TITLEAZ","Ttulo (A a Z)");
define("_TITLEZA","Ttulo (Z a A)");
define("_DATE1","Data (Links Antigos Listados Primeiro)");
define("_DATE2","Data (Links Novos Listados Primeiro)");
define("_RATING1","Classificao (Da Pontuao mais Baixa para Mais Alta)");
define("_RATING2","Classificao (Da Pontuao mais Alta para Mais Baixa)");
define("_SEARCHRESULTS4","Resultado da busca por");
define("_USUBCATEGORIES","Subcategorias");
define("_LINKS","Links");
define("_TRY2SEARCH","Experimente Procurar");
define("_INOTHERSENGINES","em outros sistemas de busca");
define("_EDITORIAL","Editorial");
define("_LINKPROFILE","Perfil doLink");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","Nenhum editorial est actualmente disponvel para este site.");
define("_VISITTHISSITE","Visite este Site");
define("_RATETHISSITE","Classifique este Recurso");
define("_ISTHISYOURSITE","Este  o seu Recurso?");
define("_ALLOWTORATE","Permita que os outros utilizadores classifiquem isto apartir do seu site !");
define("_LINKRATINGDET","Classificao Detalhado do Link");
define("_OVERALLRATING","Avaliao Global");
define("_TOTALOF","Total de");
define("_USER","Utilizadores");
define("_USERAVGRATING","A avaliao mdia do usurio");
define("_NUMRATINGS","# de Avaliaes");
define("_EDITTHISLINK","Editar Este Link");
define("_REGISTEREDUSERS","utilizadores Registrados");
define("_NUMBEROFRATINGS","Nmero de Avaliaes");
define("_NOREGUSERSVOTES","Nenhum utilizador annimo vota");
define("_BREAKDOWNBYVAL","Desarranjo de Avaliaes por valor");
define("_LTOTALVOTES","total de votos");
define("_LINKRATING","Avaliao de Links");
define("_HIGHRATING","Avaliao Alta");
define("_LOWRATING","Avaliao Baixa");
define("_NUMOFCOMMENTS","Nmero de Comentrios");
define("_WEIGHNOTE","* Nota: Este recurso conta para utilizadores registados. Avaliao de utilizador annimos");
define("_NOUNREGUSERSVOTES","Nenhum utilizador annimo vota");
define("_WEIGHOUTNOTE","* Nota: Este recurso pesa para utilizadores registados. Fora a avaliao dos eleitores");
define("_NOOUTSIDEVOTES","Nenhum voto annimo");
define("_OUTSIDEVOTERS","Votos annimos");
define("_UNREGISTEREDUSERS","utilizadores annimos");
define("_PROMOTEYOURSITE","Promova o seu web site");
define("_PROMOTE01","Talvez voc possa se interessar por alguns dos nossos sistemas de 'Avaliao de Sites' que possumos. Estes sistemas permitem colocar uma imagem (ou at mesmo uma forma de avaliao) em seu site na Web de modo que possa aumentar o nmero de visitar que voc recebe. Por favor selecione uma das opes listada abaixo:");
define("_TEXTLINK","Texto Link");
define("_PROMOTE02","Uma maneira de lincar a forma de avaliao  usar um link de texto simples:");
define("_HTMLCODE1","O cdigo em HTML que voc deveria usar neste caso,  o seguinte:");
define("_THENUMBER","Um nmero");
define("_IDREFER","em HTML referente ao nmero de indentificao do seu site que no web site do $sitename. Esteja seguro que este nmero esteja presente.");
define("_BUTTONLINK","Boto do Link");
define("_PROMOTE03","Se voc est  procura de um pouco mais que Link de texto simples, talvez voc queira um link com boto pequeno:");
define("_RATEIT","Avalie este web site!");
define("_HTMLCODE2","O cdigo fonte para o boto acima :");
define("_REMOTEFORM","Forma de Avaliao a Distncia");
define("_PROMOTE04","Se voc nos enganar, ns removeremos seu link. Temos dito isto, aqui como uma forma de avaliao remota e sria.");
define("_VOTE4THISSITE","Vote neste Site!");
define("_LINKVOTE","Vote!");
define("_HTMLCODE3","Usando desta forma permite que os utilizadores avaliem o contedo da sua pgina direto do seu site e esta avaliao ser armazenada aqui. A forma acima  invlida, mas o cdigo fonte seguinte funciona basta que voc copie e cole na sua Homepage. O cdigo fonte  mostrado abaixo:");
define("_PROMOTE05","Obrigado! E boa sorte com suas avaliaes!");
define("_STAFF","Equipe");
define("_THANKSBROKEN","Obrigado por manter a integridade deste diretrio.");
define("_THANKSFORINFO","Obrigado pela Informao.");
define("_LOOKTOREQUEST","Nossa equipe olhar em breve seu pedido.");
define("_REQUESTLINKMOD","Pedido para Modificao de Link");
define("_LINKID","Link ID");
define("_SENDREQUEST","Enviar Pedido");
define("_THANKSTOTAKETIME","Obrigado por usar seu tempo para avaliar um site aqui a");
define("_LETSDECIDE","Avaliao de utilizadores como voc ajudar para que outros visitantes decidam quais links eles desejam visitar em.");
define("_RETURNTO","Voltar para");
define("_RATENOTE1","Por favor no vote por mais de uma vez na mesma avaliao.");
define("_RATENOTE2","A escala vai de 1 - 10, sendo 1 para pobre e 10 para excelente.");
define("_RATENOTE3","Por favor seja objetivo no seu voto, pois se todo mundo receber somente 1 ou somente 10, as avaliaes no sero teis.");
define("_RATENOTE4","Voc pode ver uma lista de<a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">Top do Recursos Avaliados</a>.");
define("_RATENOTE5","No vote em voc mesmo ou em qualquer um.");
define("_YOUAREREGGED","Voc  um utilizador registado e est conectado em.");
define("_FEELFREE2ADD","Sinta-se a vontade para adicionar comentrios a este site.");
define("_YOUARENOTREGGED","Voc no  um utilizador registado ou no efetuou sue login.");
define("_IFYOUWEREREG","Se voc fosse um utilizador registado poderia enviar vrios comentrios a este site.");
define("_WEBLINKS","Web Links");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Agradecemos a sua opinio.");
define("_COMPLETEVOTE2","J votou sobre isto h $anonwaitdays dia(s).");
define("_COMPLETEVOTE3","Vote apenas uma vez.<br>Todos os votos so registados no servidor e monitorizados.");
define("_COMPLETEVOTE4","No pode votar num link que voc mesmo enviou.<br>Todos os votos so registados no servidor e monitorizados.");
define("_COMPLETEVOTE5","No realizou o preenchimento completo. O voto no seguiu.");
define("_COMPLETEVOTE6","Apenas um voto por IP permitido em cada $outsidewaitdays dia(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>

==> phpnuke-5.6.tgz: www/phpnuke/html/modules/Web_Links/language/lang-portuguese.php <==
<?php

/**************************************************************************/
/* PHP-NUKE: Advanced Content Management System                           */
/* ============================================                           */
/*                                                                        */
/* This is the language module with all the system messages               */
/*                                                                        */
/* If you made a translation, please go to the site and send to me        */
/* the translated file. Please keep the original text order by modules,   */
/* and just one message per line, also double check your translation!     */
/*                                                                        */
/* You need to change the second quoted phrase, not the capital one!      */
/*                                                                        */
/* If you need to use double quotes (") remember to add a backslash (\),  */
/* so your entry will look like: This is \"double quoted\" text.          */
/* And, if you use HTML code, please double check it.                     */
/**************************************************************************/

define("_URL","Link");
define("_PREVIOUS","Pgina Anterior");
define("_NEXT","Pgina Posterior");
define("_YOURNAME","O seu nome");
define("_CATEGORY","Categoria");
define("_CATEGORIES","Categorias");
define("_LVOTES","votos");
define("_TOTALVOTES","Total de votos:");
define("_LINKTITLE","Ttulo do Link ");
define("_HITS","Hits");
define("_THEREARE","H");
define("_NOMATCHES","Nada encontrado para");
define("_SCOMMENTS","Comentrios");
define("_DESCRIPTION","Descrio");
define("_ONLYREGUSERSMODIFY","Somente utilizadores registado podem sugerir modificaes nos arquivos para Download. Por favor <a href=\"modules.php?name=Your_Account\">registe-se ou efectue o seu login</a>.");
define("_DATE","Data");
define("_TO","Para");
define("_ADDLINK","Adicionar Link");
define("_NEW","Novo");
define("_POPULAR","Popular");
define("_TOPRATED","Melhor Colocado");
define("_RANDOM","Aleatrio");
define("_LINKSMAIN","ndice de Links");
define("_LINKCOMMENTS","Link Comentado");
define("_ADDITIONALDET","Detalhes Adicionais");
define("_EDITORREVIEW","Editor da Reviso");
define("_REPORTBROKEN","Reporte Links Invlidos");
define("_LINKSMAINCAT","ndice de Categorias de Links");
define("_AND","e");
define("_INDB","no nosso web site");
define("_ADDALINK","Adicionar Novo Link");
define("_INSTRUCTIONS","Instrues");
define("_SUBMITONCE","Envie somente uma vez um Link no envie Links iguais.");
define("_POSTPENDING","Todos os Links so verificados antes de serem publicados.");
define("_USERANDIP","So registado o nome do utilizador bem como o ip de quem enviou o Link, ento por favor no abuse ns podemos encontra-lo.");
define("_PAGETITLE","Ttulo da Pgina");
define("_PAGEURL","Endereo da Pgina");
define("_YOUREMAIL","Seu Email");
define("_LDESCRIPTION","Descrio: (255 mx. caracteres)");
define("_ADDURL","Adicionar esta URL");
define("_LINKSNOTUSER1","Voc no  um utilizador registado ou no efetuou seu login.");
define("_LINKSNOTUSER2","Se voc fosse um utilizador registado do site ento voc poderia adicionar URLS neste site.");
define("_LINKSNOTUSER3","Para se tornar um utilizador registado  rpido e simples.");
define("_LINKSNOTUSER4","Por que ns requeremos o seu registo para acessar certas reas?");
define("_LINKSNOTUSER5","Porque s assim poderemos lhe oferecer um contedo da mais alta qualidade,");
define("_LINKSNOTUSER6","pois cada item  revisado individualmente por nossa equipe.");
define("_LINKSNOTUSER7","E ns desejamos lhe oferecer somente informaes importantes.");
define("_LINKSNOTUSER8","<a href=\"modules.php?name=Your_Account\">Registe uma conta</a>");
define("_LINKALREADYEXT","ERRO: Esta URL j existe no nosso web site!");
define("_LINKNOTITLE","ERRO: Voc precisa dar uma ttulo para sua URL!");
define("_LINKNOURL","ERRO: Voc precisa digitar uma URL para sua URL!");
define("_LINKNODESC","ERRO: Voc precisa descrever sua URL!");
define("_LINKRECEIVED","Ns recebemos o seu Link. Obrigado!");
define("_EMAILWHENADD","Voc receber um Email quando este Link for aprovado.");
define("_CHECKFORIT","Voc no escreveu seu Email. De qualquer maneira nossa equipe ir conferir o seu Link");
define("_NEWLINKS","Novos Links");
define("_TOTALNEWLINKS","Total de Novos Links");
define("_LASTWEEK","Da ltima semana");
define("_LAST30DAYS","Dos ltimos 30 dias");
define("_1WEEK","1 Semana");
define("_2WEEKS","2 Semanas");
define("_30DAYS","30 Dias");
define("_SHOW","Mostar");
define("_TOTALFORLAST","Total de novos Links por ltimo");
define("_DAYS","dias");
define("_ADDEDON","Adicionado em");
define("_RATING","Pdium");
define("_RATESITE","Avalie este Site");
define("_DETAILS","Detalhes");
define("_BESTRATED","Pdium do Melhores Links - Top");
define("_OF","do");
define("_TRATEDLINKS","total de sites avaliados ");
define("_TVOTESREQ","mnimo de votos requeridos");
define("_SHOWTOP","Mostrar Top");
define("_MOSTPOPULAR","Os mais populares - top");
define("_OFALL","de todos");
define("_SORTLINKSBY","Links ordenados por");
define("_SITESSORTED","Web sites actualmente ordenados por");
define("_POPULARITY","Popularidade");
define("_SELECTPAGE","Pgina Selecionado");
define("_MAIN","ndice");
define("_NEWTODAY","Novo de Hoje");
define("_NEWLAST3DAYS","Novo dos ltimos 3 dias");
define("_NEWTHISWEEK","Novo desta Semana");
define("_CATNEWTODAY","Novos Links desta categoria adicionados Hoje");
define("_CATLAST3DAYS","Novos Links desta categoria adicionados nos ltimos 3 dias");
define("_CATTHISWEEK","Novos Links desta categoria adicionados esta semana");
define("_POPULARITY1","Popular (Mais Visitados Primeiro)");
define("_POPULARITY2","Popular (Mais Visitados por ltimos)");
define("_TITLEAZ","Ttulo (A a Z)");
define("_TITLEZA","Ttulo (Z a A)");
define("_DATE1","Data (Links Antigos Listados Primeiro)");
define("_DATE2","Data (Links Novos Listados Primeiro)");
define("_RATING1","Classificao (Da Pontuao mais Baixa para Mais Alta)");
define("_RATING2","Classificao (Da Pontuao mais Alta para Mais Baixa)");
define("_SEARCHRESULTS4","Resultado da busca por");
define("_USUBCATEGORIES","Subcategorias");
define("_LINKS","Links");
define("_TRY2SEARCH","Experimente Procurar");
define("_INOTHERSENGINES","em outros sistemas de busca");
define("_EDITORIAL","Editorial");
define("_LINKPROFILE","Perfil doLink");
define("_EDITORIALBY","Editorial por");
define("_NOEDITORIAL","Nenhum editorial est actualmente disponvel para este site.");
define("_VISITTHISSITE","Visite este Site");
define("_RATETHISSITE","Classifique este Recurso");
define("_ISTHISYOURSITE","Este  o seu Recurso?");
define("_ALLOWTORATE","Permita que os outros utilizadores classifiquem isto apartir do seu site !");
define("_LINKRATINGDET","Classificao Detalhado do Link");
define("_OVERALLRATING","Avaliao Global");
define("_TOTALOF","Total de");
define("_USER","Utilizadores");
define("_USERAVGRATING","A avaliao mdia do usurio");
define("_NUMRATINGS","# de Avaliaes");
define("_EDITTHISLINK","Editar Este Link");
define("_REGISTEREDUSERS","utilizadores Registrados");
define("_NUMBEROFRATINGS","Nmero de Avaliaes");
define("_NOREGUSERSVOTES","Nenhum utilizador annimo vota");
define("_BREAKDOWNBYVAL","Desarranjo de Avaliaes por valor");
define("_LTOTALVOTES","total de votos");
define("_LINKRATING","Avaliao de Links");
define("_HIGHRATING","Avaliao Alta");
define("_LOWRATING","Avaliao Baixa");
define("_NUMOFCOMMENTS","Nmero de Comentrios");
define("_WEIGHNOTE","* Nota: Este recurso conta para utilizadores registados. Avaliao de utilizador annimos");
define("_NOUNREGUSERSVOTES","Nenhum utilizador annimo vota");
define("_WEIGHOUTNOTE","* Nota: Este recurso pesa para utilizadores registados. Fora a avaliao dos eleitores");
define("_NOOUTSIDEVOTES","Nenhum voto annimo");
define("_OUTSIDEVOTERS","Votos annimos");
define("_UNREGISTEREDUSERS","utilizadores annimos");
define("_PROMOTEYOURSITE","Promova o seu web site");
define("_PROMOTE01","Talvez voc possa se interessar por alguns dos nossos sistemas de 'Avaliao de Sites' que possumos. Estes sistemas permitem colocar uma imagem (ou at mesmo uma forma de avaliao) em seu site na Web de modo que possa aumentar o nmero de visitar que voc recebe. Por favor selecione uma das opes listada abaixo:");
define("_TEXTLINK","Texto Link");
define("_PROMOTE02","Uma maneira de lincar a forma de avaliao  usar um link de texto simples:");
define("_HTMLCODE1","O cdigo em HTML que voc deveria usar neste caso,  o seguinte:");
define("_THENUMBER","Um nmero");
define("_IDREFER","em HTML referente ao nmero de indentificao do seu site que no web site do $sitename. Esteja seguro que este nmero esteja presente.");
define("_BUTTONLINK","Boto do Link");
define("_PROMOTE03","Se voc est  procura de um pouco mais que Link de texto simples, talvez voc queira um link com boto pequeno:");
define("_RATEIT","Avalie este web site!");
define("_HTMLCODE2","O cdigo fonte para o boto acima :");
define("_REMOTEFORM","Forma de Avaliao a Distncia");
define("_PROMOTE04","Se voc nos enganar, ns removeremos seu link. Temos dito isto, aqui como uma forma de avaliao remota e sria.");
define("_VOTE4THISSITE","Vote neste Site!");
define("_LINKVOTE","Vote!");
define("_HTMLCODE3","Usando desta forma permite que os utilizadores avaliem o contedo da sua pgina direto do seu site e esta avaliao ser armazenada aqui. A forma acima  invlida, mas o cdigo fonte seguinte funciona basta que voc copie e cole na sua Homepage. O cdigo fonte  mostrado abaixo:");
define("_PROMOTE05","Obrigado! E boa sorte com suas avaliaes!");
define("_STAFF","Equipe");
define("_THANKSBROKEN","Obrigado por manter a integridade deste diretrio.");
define("_THANKSFORINFO","Obrigado pela Informao.");
define("_LOOKTOREQUEST","Nossa equipe olhar em breve seu pedido.");
define("_REQUESTLINKMOD","Pedido para Modificao de Link");
define("_LINKID","Link ID");
define("_SENDREQUEST","Enviar Pedido");
define("_THANKSTOTAKETIME","Obrigado por usar seu tempo para avaliar um site aqui a");
define("_LETSDECIDE","Avaliao de utilizadores como voc ajudar para que outros visitantes decidam quais links eles desejam visitar em.");
define("_RETURNTO","Voltar para");
define("_RATENOTE1","Por favor no vote por mais de uma vez na mesma avaliao.");
define("_RATENOTE2","A escala vai de 1 - 10, sendo 1 para pobre e 10 para excelente.");
define("_RATENOTE3","Por favor seja objetivo no seu voto, pois se todo mundo receber somente 1 ou somente 10, as avaliaes no sero teis.");
define("_RATENOTE4","Voc pode ver uma lista de<a href=\"modules.php?name=Web_Links&amp;l_op=TopRated\">Top do Recursos Avaliados</a>.");
define("_RATENOTE5","No vote em voc mesmo ou em qualquer um.");
define("_YOUAREREGGED","Voc  um utilizador registado e est conectado em.");
define("_FEELFREE2ADD","Sinta-se a vontade para adicionar comentrios a este site.");
define("_YOUARENOTREGGED","Voc no  um utilizador registado ou no efetuou sue login.");
define("_IFYOUWEREREG","Se voc fosse um utilizador registado poderia enviar vrios comentrios a este site.");
define("_WEBLINKS","Web Links");
define("_TITLE","Ttulo");
define("_MODIFY","Modificar");
define("_COMPLETEVOTE1","Agradecemos a sua opinio.");
define("_COMPLETEVOTE2","J votou sobre isto h $anonwaitdays dia(s).");
define("_COMPLETEVOTE3","Vote apenas uma vez.<br>Todos os votos so registados no servidor e monitorizados.");
define("_COMPLETEVOTE4","No pode votar num link que voc mesmo enviou.<br>Todos os votos so registados no servidor e monitorizados.");
define("_COMPLETEVOTE5","No realizou o preenchimento completo. O voto no seguiu.");
define("_COMPLETEVOTE6","Apenas um voto por IP permitido em cada $outsidewaitdays dia(s).");
define("_LINKSDATESTRING","%d-%b-%Y");

?>
